==> kadu-0.12.2.tar.bz2: kadu-0.12.2/plugins/config_wizard/translations/config_wizard_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu doit être redémarré avant que la modification de langue prenne effet.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration du compte&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Réseau IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Je veux choisir un compte existant pour Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Je veux créer un nouveau compte pour Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Je ne veux pas choisir mon compte pour Kadu maintenant</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Veuillez choisir le réseau pour le compte que vous voulez configurer.&lt;/p&gt;&lt;p&gt;Vous pouvez aussi créer un nouveau compte avec l&apos;assistant si vous ne l&apos;avez pas déjà fait.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Assistant de configuration terminé&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Aller à &quot;Configuration du compte&quot; après avoir fermer cette fenêtre</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirmez les paramètres de l&apos;assistant pour commencer à utiliser Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard...</source>
        <translation>Lancer l&apos;assistant de configuration...</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Bienvenu dans la Messagerie Instantanée Kadu&lt;/h3&gt;&lt;p&gt;Cet assistant vous aidera à configurer le paramètres principaux de Kadu.&lt;/p&gt;&lt;p&gt;Veuillez choisir votre langue préférée et créer un pseudonyme&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration du profil&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonyme</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration du compte&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Veuillez saisir les informations de votre compte.&lt;/p&gt;&lt;p&gt;Retournez en arrière si vous voulez choisir une autre option de configuration du compte.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Assitant Kadu</translation>
    </message>
</context>
</TS>

==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/config_wizard/translations/config_wizard_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu doit être redémarré avant que la modification de langue prenne effet.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration du compte&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Réseau IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Je veux choisir un compte existant pour Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Je veux créer un nouveau compte pour Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Je ne veux pas choisir mon compte pour Kadu maintenant</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Veuillez choisir le réseau pour le compte que vous voulez configurer.&lt;/p&gt;&lt;p&gt;Vous pouvez aussi créer un nouveau compte avec l&apos;assistant si vous ne l&apos;avez pas déjà fait.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Assistant de configuration terminé&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Aller à &quot;Configuration du compte&quot; après avoir fermer cette fenêtre</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirmez les paramètres de l&apos;assistant pour commencer à utiliser Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Lancer l&apos;assistant de configuration</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Bienvenu dans la Messagerie Instantanée Kadu&lt;/h3&gt;&lt;p&gt;Cet assistant vous aidera à configurer le paramètres principaux de Kadu.&lt;/p&gt;&lt;p&gt;Veuillez choisir votre langue préférée et créer un pseudonyme&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration du profil&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonyme</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration du compte&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Veuillez saisir les informations de votre compte.&lt;/p&gt;&lt;p&gt;Retournez en arrière si vous voulez choisir une autre option de configuration du compte.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Assitant Kadu</translation>
    </message>
</context>
</TS>
